<?php

/**
 * @file
 * Contains \Drupal\onehub\Form\OneHubAuthorizeForm.
 */

namespace Drupal\onehub\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\onehub\OneHubOauth;
use Drupal\onehub\OneHubAPI;

class OneHubAuthorizeForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'onehub_authorize_form';
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {
    // Check both methods to make sure we have auth.
    /**
     * @todo DI the config to the form.
     */
    $token = \Drupal::config('onehub.settings')->get('onehub_access_token');

    // If we have a token.
    if (!empty($token)) {
      $oh = new OneHubAPI();
      $api = $oh->checkToken();
    }

    // Show the submit or not.
    if (empty($token) || !$api) {
      // We are not Authorized, instruct the people.
      $form['title'] = [
        '#type' => 'item',
        '#markup' => '<center><h3>OneHub is not authorized on this site.  Click Authorize below and follow the prompts.<h3></center>',
      ];

      $form['submit'] = [
        '#type' => 'submit',
        '#value' => t('Authorize'),
        '#prefix' => '<center>',
        '#suffix' => '</center>',
      ];
    }
    else {
      // We are good!
      $form['title'] = [
        '#type' => 'item',
        '#markup' => '<center><h3>OneHub is authorized, you may carry on.<h3></center>',
      ];
    }

    return $form;
  }

  public function validateForm(array &$form, \Drupal\Core\Form\FormStateInterface $form_state) {
    // Instantiate the OneHub request and grab the code.
    $oh = new OneHubOauth();
    $oh->getAuthCode();
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}
}
