<?php

namespace Drupal\onehub;

use Drupal\onehub\Blackbaud;

/**
 * Class BlackbaudAPI.
 *
 * @package Drupal\onehub
 */
class OneHubAPI extends OneHub {


  /**
   * Sets the typical headers needed for an api call.
   *
   * @return array
   *   the headers for the api call.
   */
  protected function setAPIHeaders() {
    // Grab the access token.
    $token = parent::getToken('access');

    // Return the set headers for an API call.
    return array(
      'headers' => array(
        'Authorization' => 'Bearer ' . $token,
      ),
    );
  }

  /**
   * Mechanism to call the API.
   *
   * @param string $endpoint
   *   The endpoint url without the BASEapi url
   *
   * @return null|object
   *   The API response or NULL.
   */
  public function callAPI($endpoint) {
    parent::setURL($this->base_url . $endpoint);
    parent::requestResponse('GET', $this->setAPIHeaders());

    // Exit if Empty Response.
    if (is_null($this->request)) {
      return NULL;
    }

    // Grab the Body and return as needed.
    $contents = json_decode($this->request->getBody()->getContents());
    return !empty($contents) ? $contents : NULL;
  }

  /**
   * Pings a simple api call to test if the token is valid.
   *
   * @return boolean
   *   If we are able to ping the API or not.
   */
  public function checkToken() {
    $check = $this->callAPI('/workspaces');
    return is_null($check) ? FALSE : TRUE;
  }
}
